@@ -1,7 +1,7 @@
 """
 Type annotations for chime-sdk-identity service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/literals/)
 
 Usage::
 
@@ -27,6 +27,7 @@ __all__ = (
     "ChimeSDKIdentityServiceName",
     "ServiceName",
     "ResourceServiceName",
+    "RegionName",
 )
 
 
@@ -153,6 +154,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -350,3 +352,4 @@ ResourceServiceName = Literal[
     "sns",
     "sqs",
 ]
+RegionName = Literal["us-east-1"]
